@@ -19,6 +19,8 @@ var libeis_8h =
       [ "EIS_EVENT_CLIENT_DISCONNECT", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba308dd75e0c40d8b6773f9949ab2d1d83", null ],
       [ "EIS_EVENT_SEAT_BIND", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbbade4f97145108c150e315a856b8471d1e", null ],
       [ "EIS_EVENT_DEVICE_CLOSED", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba5ccc8660e714bf693d21559aa08a20d9", null ],
+      [ "EIS_EVENT_PONG", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba2f1c2b3770057880e0c55eb0b5d6807d", null ],
+      [ "EIS_EVENT_SYNC", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba88592bed8435c8022d145320dd5aba60", null ],
       [ "EIS_EVENT_FRAME", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba951c1b8e54e7f19a866d8412da0b4f0d", null ],
       [ "EIS_EVENT_DEVICE_START_EMULATING", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba23f5a32ccab7d4f9543e546afd9e6b92", null ],
       [ "EIS_EVENT_DEVICE_STOP_EMULATING", "group__libeis.html#gga3287e79a6ffcdb8f13573a6d4f9bfbbba9a756ac655536795c5e46931dc46e6f8", null ],
@@ -50,6 +52,7 @@ var libeis_8h =
     [ "eis_client_get_name", "group__libeis.html#ga701de8148a117e3c330e7813661e15bc", null ],
     [ "eis_client_get_user_data", "group__libeis.html#ga89fbbabfbcd1990e651fd1fd70044edd", null ],
     [ "eis_client_is_sender", "group__libeis.html#ga3fe13b4dea5fa88fc05e397b88cc68fd", null ],
+    [ "eis_client_new_ping", "group__libeis.html#ga3b35770369ad947ef5b1cd3fe4a735ba", null ],
     [ "eis_client_new_seat", "group__libeis.html#ga42dbc6a5cde697762fbf3f9520daff3f", null ],
     [ "eis_client_ref", "group__libeis.html#gadc8186e32b93c00204b7090f63fa756a", null ],
     [ "eis_client_set_user_data", "group__libeis.html#ga17b0cab07d25a8ac7b325fedc9420802", null ],
@@ -108,6 +111,7 @@ var libeis_8h =
     [ "eis_event_pointer_get_absolute_y", "group__libeis-sender.html#gad7a06ae46dce11d2554325a258b5f56c", null ],
     [ "eis_event_pointer_get_dx", "group__libeis-sender.html#gaf6f044753909a90e6b95c9ea9bb6e81b", null ],
     [ "eis_event_pointer_get_dy", "group__libeis-sender.html#gac1e85d503bf4f36ea38775dd4ab0c7c2", null ],
+    [ "eis_event_pong_get_ping", "group__libeis.html#ga5317a721145a0465c8ee5e3b8e819d5b", null ],
     [ "eis_event_scroll_get_discrete_dx", "group__libeis-sender.html#ga6aa0b54100ae86bbfa012416af073c7c", null ],
     [ "eis_event_scroll_get_discrete_dy", "group__libeis-sender.html#ga610cb0b302d816d630a676a161e9192a", null ],
     [ "eis_event_scroll_get_dx", "group__libeis-sender.html#ga6ac8482707400828fc7f3f4889efc1a1", null ],
@@ -116,6 +120,7 @@ var libeis_8h =
     [ "eis_event_scroll_get_stop_y", "group__libeis-sender.html#gaaf9cfc77e7daf396b53609ecf344c428", null ],
     [ "eis_event_seat_has_capability", "group__libeis.html#gafa127cbddb71311193e07541b1f1c75d", null ],
     [ "eis_event_touch_get_id", "group__libeis-sender.html#ga3359817c6106c139d1e3ca487f1ece2a", null ],
+    [ "eis_event_touch_get_is_cancel", "group__libeis-sender.html#ga98689c3df87a93b7f202e531365851e2", null ],
     [ "eis_event_touch_get_x", "group__libeis-sender.html#ga563f03da5ad0132f5c671a5f3485c20f", null ],
     [ "eis_event_touch_get_y", "group__libeis-sender.html#gab6ec3a3e2734c2bc2d98a3f31b0c1640", null ],
     [ "eis_event_type_to_string", "group__libeis.html#ga053398fc33056cde10d74e049662904d", null ],
@@ -141,6 +146,12 @@ var libeis_8h =
     [ "eis_new", "group__libeis.html#ga63fedbac98010b1cb1bd3e5337038061", null ],
     [ "eis_now", "group__libeis.html#gacf9d41645c32c494bc41e8034200e1ae", null ],
     [ "eis_peek_event", "group__libeis.html#ga963f72c1ca469415509d51e31b842379", null ],
+    [ "eis_ping", "group__libeis.html#ga55fd8fc3ad8429c000bb68c8420de818", null ],
+    [ "eis_ping_get_id", "group__libeis.html#gacda0204897e2cb8c39f2c8af78514b9e", null ],
+    [ "eis_ping_get_user_data", "group__libeis.html#gad8ac37a051829a77cd682f6261b0eb63", null ],
+    [ "eis_ping_ref", "group__libeis.html#gae16325662101b4c1ffb3ffaf48938c08", null ],
+    [ "eis_ping_set_user_data", "group__libeis.html#ga6c969f629ca64cc38047d42d1f8a44b6", null ],
+    [ "eis_ping_unref", "group__libeis.html#gac6cf11f783d3ee4149ee308279326a6f", null ],
     [ "eis_ref", "group__libeis.html#ga7660f7d3079be407553f2191fa34e53b", null ],
     [ "eis_region_add", "group__libeis-region.html#ga2a67457c09e363be9c55aad7680fac72", null ],
     [ "eis_region_contains", "group__libeis-region.html#ga7dd89ab7cd73229daa8484877d394ff9", null ],
@@ -173,6 +184,7 @@ var libeis_8h =
     [ "eis_set_user_data", "group__libeis.html#ga90a8abf6e9433cb267781edc540fe405", null ],
     [ "eis_setup_backend_fd", "group__libeis.html#gade5cc09b2c6c2c7c90bf3f2b968cdb56", null ],
     [ "eis_setup_backend_socket", "group__libeis.html#gad615c678d89c16c124f299f08388da7c", null ],
+    [ "eis_touch_cancel", "group__libeis-receiver.html#ga66eab021e4641e8c6fc13b2e8e2dd90a", null ],
     [ "eis_touch_down", "group__libeis-receiver.html#gab7679b3dd4bb18a5dd39a85ed259eb35", null ],
     [ "eis_touch_get_device", "group__libeis-receiver.html#gae691795024ff182b5d3066316f0c2c3b", null ],
     [ "eis_touch_get_user_data", "group__libeis-receiver.html#ga2d5636e19c2c850cd01fab1310b69ade", null ],
